"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const isXProperty = (propertyPath) => {
    return propertyPath.startsWith('x-');
};
const getXPropertiesInObject = (object) => {
    const topLevelPropertiesArray = [];
    _.forIn(object, (value, key) => {
        if (isXProperty(key)) {
            topLevelPropertiesArray.push({ key, value });
        }
    });
    return topLevelPropertiesArray;
};
const parseTopLevelArrayProperties = (arrayName, inputArray) => {
    const parsedSchemesArray = [];
    if (inputArray.length) {
        inputArray.forEach((value, index) => {
            parsedSchemesArray.push({
                originalPath: [arrayName, index.toString()],
                value
            });
        });
    }
    return parsedSchemesArray;
};
const parseSwagger2Spec = (swagger2Spec) => {
    const parsedSpec = {
        basePath: {
            originalPath: ['basePath'],
            value: swagger2Spec.basePath
        },
        format: 'swagger2',
        schemes: {
            originalPath: ['schemes'],
            value: swagger2Spec.schemes ? parseTopLevelArrayProperties('schemes', swagger2Spec.schemes) : undefined
        },
        xProperties: {}
    };
    for (const entry of getXPropertiesInObject(swagger2Spec)) {
        _.set(parsedSpec.xProperties, entry.key, { originalPath: [entry.key], value: entry.value });
    }
    return parsedSpec;
};
const parseOpenApi3Spec = (openApi3Spec) => {
    const parsedSpec = {
        basePath: {
            originalPath: ['basePath'],
            value: undefined
        },
        format: 'openapi3',
        schemes: {
            originalPath: ['schemes'],
            value: undefined
        },
        xProperties: {}
    };
    for (const entry of getXPropertiesInObject(openApi3Spec)) {
        _.set(parsedSpec.xProperties, entry.key, { originalPath: [entry.key], value: entry.value });
    }
    return parsedSpec;
};
const isSwagger2 = (spec) => {
    return !!spec.swagger;
};
exports.specParser = {
    parse: (spec) => {
        return isSwagger2(spec)
            ? parseSwagger2Spec(spec)
            : parseOpenApi3Spec(spec);
    }
};
